@@ -1,14 +1,14 @@
-# Copyrights 2001-2021 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2022 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.02.
+# Pod stripped from pm file by OODoc 2.03.
 # This code is part of distribution Mail-Message.  Meta-POD processed with
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Message::Field::Structured;
 use vars '$VERSION';
-$VERSION = '3.011';
+$VERSION = '3.012';
 
 use base 'Mail::Message::Field::Full';
 
@@ -54,7 +54,7 @@ sub attribute($;$)
     }
 
     delete $self->{MMFF_body};
-    $self->{MMFS_attrs}{$name} = $attr;
+    $self->{MMFS_attrs}{lc $name} = $attr;
 }
 
 
